# Changelog

## Version 25.1.0 (2025-06-22)

All dependencies have been updated to recent versions. Please rebuild the environment.

### New Features:

- Added Schaefer atlas-based parcel labels for ICBM152 and Colin27 head models via FreeSurfer surface mapping, by [Shakiba Moradi](https://github.com/shakiba93).
- Spatial and measurement noise regularization options in image reconstruction,  by [David Boas](https://github.com/dboas). ([#86](https://github.com/ibs-lab/cedalion/pull/86))
- Improved import of optode and electrode coordinates, by [Nils Harmening](https://github.com/harmening). ([#95](https://github.com/ibs-lab/cedalion/pull/95))
- The interfaces for the fluence and sensitivity computations were changed to allow out-of-core computations, by [Eike Middell](https://github.com/emiddell).
- Precomputed sensitivities for all example datasets, including the ninjaCap whole head probe, are availabe in cedalion.datasets, by [Eike Middell](https://github.com/emiddell).

- Make all example notebooks run on Google Colab integration, by [Josef Cutler](https://github.com/jccutler). ([#96](https://github.com/ibs-lab/cedalion/pull/96))

- Added functionality to add synthetic HRFs to resting state data, 
  by [Thomas Fischer](https://github.com/thomasfischer11). ([#77](https://github.com/ibs-lab/cedalion/pull/77))
- Added functionality to add synthetic artifacts to fNIRS data , by [Josef Cutler](https://github.com/jccutler).

- Added AMPD algorithm for heart beat detection from {cite:p}`Scholkmann2012`, by [Isa Musisi](https://github.com/isamusisi).
- Functionality for global physiology removal, by [Alexander von Lühmann](https://github.com/avolu). ([#106](https://github.com/ibs-lab/cedalion/pull/106))

- Multimodal source decomposition methods, including most CCA variants, by [Tomas Codina](https://github.com/TCodina). ([#102](https://github.com/ibs-lab/cedalion/pull/102))
- The interface to fit GLMs changed. The GLM solver is now based on statsmodels and we integrated the AR-IRLS algorithm, by [Ted Huppert](https://github.com/huppertt) and [Eike Middell](https://github.com/emiddell). ([#68](https://github.com/ibs-lab/cedalion/pull/68))
- Added wavelet motion correction from {cite:p}`Molavi2012`, by [Josef Cutler](https://github.com/jccutler). ([#72](https://github.com/ibs-lab/cedalion/pull/72))

- New multi-view animated image reconstruction plots, by [David Boas](https://github.com/dboas) and [Alexander von Lühmann](https://github.com/avolu).
- Thresholding and visualizing probe sensitivity to brain parcels, by [Alexander von Lühmann](https://github.com/avolu).
- Improvements to the time-series plots, by [David Boas](https://github.com/dboas). ([#85](https://github.com/ibs-lab/cedalion/pull/85), [#108](https://github.com/ibs-lab/cedalion/pull/108))


### Bugfixes:
- Correct determination of Cz in LandmarksBuilder1010, by [Nils Harmening](https://github.com/harmening). ([#82](https://github.com/ibs-lab/cedalion/pull/82))




## Version 25.0.0 (2025-01-21)

- First named release with contributions from:
    - [Sung Ahn](https://github.com/ahns97)
    - [Jacqueline Behrendt](https://github.com/jackybehrendt12)
    - [David Boas](https://github.com/dboas)
    - [Laura Carlton](https://github.com/lauracarlton)
    - [Tomás Codina](https://github.com/TCodina)
    - [Josef Cutler](https://github.com/jccutler)
    - [Qianqian Fang](https://github.com/fangq)
    - [Thomas Fischer](https://github.com/thomasfischer11)
    - [Nils Harmening](https://github.com/harmening)
    - [Mariia Iudina](https://github.com/mashayu)
    - [Filip Jenko](https://github.com/FilipJenko)
    - [Eike Middell](https://github.com/emiddell)
    - [Shakiba Moradi](https://github.com/shakiba93)
    - [Alexander von Lühmann](https://github.com/avolu)
    
    
    
    
    
    
    
    
    
    
    
